@@ -17,6 +17,7 @@
 
 
 #include "geojson_printer.h"
+#include "gnss_sdr_filesystem.h"
 #include "pvt_solution.h"
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <glog/logging.h>
@@ -26,31 +27,10 @@
 #include <iostream>   // for cout, cerr
 #include <sstream>    // for stringstream
 
-// clang-format off
-#if HAS_STD_FILESYSTEM
-#include <system_error>
-namespace errorlib = std;
-#if HAS_STD_FILESYSTEM_EXPERIMENTAL
-#include <experimental/filesystem>
-namespace fs = std::experimental::filesystem;
-#else
-#include <filesystem>
-namespace fs = std::filesystem;
-#endif
-#else
-#include <boost/filesystem/operations.hpp>   // for create_directories, exists
-#include <boost/filesystem/path.hpp>         // for path, operator<<
-#include <boost/filesystem/path_traits.hpp>  // for filesystem
-#include <boost/system/error_code.hpp>       // for error_code
-namespace fs = boost::filesystem;
-namespace errorlib = boost::system;
-#endif
-// clang-format on
 
-GeoJSON_Printer::GeoJSON_Printer(const std::string& base_path)
+GeoJSON_Printer::GeoJSON_Printer(const std::string& base_path) : geojson_base_path(base_path),
+                                                                 first_pos(true)
 {
-    first_pos = true;
-    geojson_base_path = base_path;
     fs::path full_path(fs::current_path());
     const fs::path p(geojson_base_path);
     if (!fs::exists(p))
