@@ -17,6 +17,7 @@
 
 
 #include "gpx_printer.h"
+#include "gnss_sdr_filesystem.h"
 #include "pvt_solution.h"
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <glog/logging.h>
@@ -26,33 +27,11 @@
 #include <iostream>   // for cout, cerr
 #include <sstream>    // for stringstream
 
-// clang-format off
-#if HAS_STD_FILESYSTEM
-#include <system_error>
-namespace errorlib = std;
-#if HAS_STD_FILESYSTEM_EXPERIMENTAL
-#include <experimental/filesystem>
-namespace fs = std::experimental::filesystem;
-#else
-#include <filesystem>
-namespace fs = std::filesystem;
-#endif
-#else
-#include <boost/filesystem/operations.hpp>   // for create_directories, exists
-#include <boost/filesystem/path.hpp>         // for path, operator<<
-#include <boost/filesystem/path_traits.hpp>  // for filesystem
-#include <boost/system/error_code.hpp>       // for error_code
-namespace fs = boost::filesystem;
-namespace errorlib = boost::system;
-#endif
-// clang-format on
 
-
-Gpx_Printer::Gpx_Printer(const std::string& base_path)
+Gpx_Printer::Gpx_Printer(const std::string& base_path) : indent("  "),
+                                                         gpx_base_path(base_path),
+                                                         positions_printed(false)
 {
-    positions_printed = false;
-    indent = "  ";
-    gpx_base_path = base_path;
     fs::path full_path(fs::current_path());
     const fs::path p(gpx_base_path);
     if (!fs::exists(p))
