@@ -19,6 +19,7 @@
 Pvt_Conf::Pvt_Conf()
 {
     type_of_receiver = 0U;
+    observable_interval_ms = 20U;
     output_rate_ms = 0;
     display_rate_ms = 0;
     kml_rate_ms = 1000;
@@ -29,7 +30,7 @@ Pvt_Conf::Pvt_Conf()
     max_obs_block_rx_clock_offset_ms = 40;
     rinex_version = 0;
     rinexobs_rate_ms = 0;
-    rinex_name = "-";
+    rinex_name = std::string("-");
 
     dump = false;
     dump_mat = true;
@@ -61,8 +62,13 @@ Pvt_Conf::Pvt_Conf()
 
     enable_rx_clock_correction = true;
     monitor_enabled = false;
+    monitor_ephemeris_enabled = false;
     protobuf_enabled = true;
     udp_port = 0;
+    udp_eph_port = 0;
     pre_2009_file = false;
     show_local_time_zone = false;
+
+    log_source_timetag = false;
+    log_source_timetag_file = "PVT_timetag.dat";
 }
