@@ -19,8 +19,8 @@
 #include "Galileo_E1.h"
 #include "configuration_interface.h"
 #include "galileo_e1_signal_replica.h"
+#include "gnss_sdr_fft.h"
 #include "gnss_sdr_flags.h"
-#include "gnss_sdr_make_unique.h"
 #include "uio_fpga.h"
 #include <glog/logging.h>
 #include <gnuradio/fft/fft.h>     // for fft_complex
@@ -35,7 +35,11 @@ GalileoE1PcpsAmbiguousAcquisitionFpga::GalileoE1PcpsAmbiguousAcquisitionFpga(
     const ConfigurationInterface* configuration,
     const std::string& role,
     unsigned int in_streams,
-    unsigned int out_streams) : role_(role),
+    unsigned int out_streams) : gnss_synchro_(nullptr),
+                                role_(role),
+                                doppler_center_(0),
+                                channel_(0),
+                                doppler_step_(0),
                                 in_streams_(in_streams),
                                 out_streams_(out_streams)
 {
@@ -92,10 +96,10 @@ GalileoE1PcpsAmbiguousAcquisitionFpga::GalileoE1PcpsAmbiguousAcquisitionFpga(
 
     // compute all the GALILEO E1 PRN Codes (this is done only once in the class constructor in order to avoid re-computing the PRN codes every time
     // a channel is assigned)
-    auto fft_if = std::make_unique<gr::fft::fft_complex>(nsamples_total, true);  // Direct FFT
-    volk_gnsssdr::vector<std::complex<float>> code(nsamples_total);              // buffer for the local code
+    auto fft_if = gnss_fft_fwd_make_unique(nsamples_total);          // Direct FFT
+    volk_gnsssdr::vector<std::complex<float>> code(nsamples_total);  // buffer for the local code
     volk_gnsssdr::vector<gr_complex> fft_codes_padded(nsamples_total);
-    d_all_fft_codes_ = std::vector<uint32_t>(nsamples_total * GALILEO_E1_NUMBER_OF_CODES);  // memory containing all the possible fft codes for PRN 0 to 32
+    d_all_fft_codes_ = volk_gnsssdr::vector<uint32_t>(nsamples_total * GALILEO_E1_NUMBER_OF_CODES);  // memory containing all the possible fft codes for PRN 0 to 32
 
     float max;  // temporary maxima search
     int32_t tmp;
@@ -172,10 +176,6 @@ GalileoE1PcpsAmbiguousAcquisitionFpga::GalileoE1PcpsAmbiguousAcquisitionFpga(
 
     acquisition_fpga_ = pcps_make_acquisition_fpga(acq_parameters);
 
-    channel_ = 0;
-    doppler_step_ = 0;
-    gnss_synchro_ = nullptr;
-
     if (in_streams_ > 1)
         {
             LOG(ERROR) << "This implementation only supports one input stream";
@@ -189,8 +189,8 @@ GalileoE1PcpsAmbiguousAcquisitionFpga::GalileoE1PcpsAmbiguousAcquisitionFpga(
 
 void GalileoE1PcpsAmbiguousAcquisitionFpga::stop_acquisition()
 {
-    // this command causes the SW to reset the HW.
-    acquisition_fpga_->reset_acquisition();
+    // stop the acquisition and the other FPGA modules.
+    acquisition_fpga_->stop_acquisition();
 }
 
 
