@@ -25,6 +25,7 @@
 #include "gnss_synchro.h"
 #include "pcps_acquisition.h"
 #include <gnuradio/blocks/float_to_complex.h>
+#include <volk_gnsssdr/volk_gnsssdr_alloc.h>
 #include <memory>
 #include <string>
 #include <vector>
@@ -157,7 +158,7 @@ public:
 
 private:
     pcps_acquisition_sptr acquisition_;
-    std::vector<std::complex<float>> code_;
+    volk_gnsssdr::vector<std::complex<float>> code_;
     gr::blocks::float_to_complex::sptr float_to_complex_;
     complex_byte_to_float_x2_sptr cbyte_to_float_x2_;
     std::weak_ptr<ChannelFsm> channel_fsm_;
