@@ -35,9 +35,9 @@
 #define GNSS_SDR_PCPS_ASSISTED_ACQUISITION_CC_H
 
 #include "channel_fsm.h"
+#include "gnss_sdr_fft.h"
 #include "gnss_synchro.h"
 #include <gnuradio/block.h>
-#include <gnuradio/fft/fft.h>
 #include <gnuradio/gr_complex.h>
 #include <fstream>
 #include <memory>
@@ -198,13 +198,8 @@ private:
     void redefine_grid();
 
     std::weak_ptr<ChannelFsm> d_channel_fsm;
-#if GNURADIO_FFT_USES_TEMPLATES
-    std::unique_ptr<gr::fft::fft_complex_fwd> d_fft_if;
-    std::unique_ptr<gr::fft::fft_complex_rev> d_ifft;
-#else
-    std::unique_ptr<gr::fft::fft_complex> d_fft_if;
-    std::unique_ptr<gr::fft::fft_complex> d_ifft;
-#endif
+    std::unique_ptr<gnss_fft_complex_fwd> d_fft_if;
+    std::unique_ptr<gnss_fft_complex_rev> d_ifft;
 
     std::vector<std::vector<std::complex<float>>> d_grid_doppler_wipeoffs;
     std::vector<std::vector<float>> d_grid_data;
@@ -224,7 +219,16 @@ private:
     float d_doppler_freq;
     float d_input_power;
     float d_test_statistics;
+
+    uint32_t d_doppler_resolution;
+    uint32_t d_channel;
+    uint32_t d_sampled_ms;
+    uint32_t d_code_phase;
+
     int32_t d_samples_per_ms;
+
+    uint32_t d_fft_size;
+
     int32_t d_max_dwells;
     int32_t d_gnuradio_forecast_samples;
     int32_t d_doppler_max;
@@ -235,11 +239,6 @@ private:
     int32_t d_doppler_step;
     int32_t d_state;
     int32_t d_well_count;
-    uint32_t d_doppler_resolution;
-    uint32_t d_channel;
-    uint32_t d_sampled_ms;
-    uint32_t d_fft_size;
-    uint32_t d_code_phase;
 
     bool d_active;
     bool d_disable_assist;
