@@ -40,10 +40,10 @@
 #define CL_SILENCE_DEPRECATION
 #include "channel_fsm.h"
 #include "gnss_block_interface.h"
+#include "gnss_sdr_fft.h"
 #include "gnss_synchro.h"
 #include "opencl/fft_internal.h"
 #include <gnuradio/block.h>
-#include <gnuradio/fft/fft.h>
 #include <gnuradio/gr_complex.h>
 #include "opencl/cl.hpp"
 #include <cstdint>
@@ -239,8 +239,8 @@ private:
 
     std::weak_ptr<ChannelFsm> d_channel_fsm;
 
-    std::unique_ptr<gr::fft::fft_complex> d_fft_if;
-    std::unique_ptr<gr::fft::fft_complex> d_ifft;
+    std::unique_ptr<gnss_fft_complex_fwd> d_fft_if;
+    std::unique_ptr<gnss_fft_complex_rev> d_ifft;
 
     std::vector<std::vector<gr_complex>> d_grid_doppler_wipeoffs;
     std::vector<std::vector<gr_complex>> d_in_buffer;
