@@ -23,7 +23,8 @@
 #include "telemetry_decoder_interface.h"
 #include "tracking_interface.h"
 #include <glog/logging.h>
-#include <utility>  // for std::move
+#include <stdexcept>  // for std::invalid_argument
+#include <utility>    // for std::move
 
 
 Channel::Channel(const ConfigurationInterface* configuration,
@@ -88,8 +89,8 @@ Channel::Channel(const ConfigurationInterface* configuration,
     acq_->set_threshold(threshold);
 
     acq_->init();
-
-    repeat_ = configuration->property("Acquisition_" + signal_str + std::to_string(channel_) + ".repeat_satellite", false);
+    repeat_ = configuration->property("Acquisition_" + signal_str + ".repeat_satellite", false);
+    repeat_ = configuration->property("Acquisition_" + signal_str + std::to_string(channel_) + ".repeat_satellite", repeat_);
     DLOG(INFO) << "Channel " << channel_ << " satellite repeat = " << repeat_;
 
     channel_fsm_->set_acquisition(acq_);
@@ -113,6 +114,13 @@ void Channel::connect(gr::top_block_sptr top_block)
             acq_->connect(top_block);
         }
     trk_->connect(top_block);
+
+    if (trk_->item_size() == 0)
+        {
+            std::string msg = trk_->role() + ".item_type is not defined for implementation " + trk_->implementation() + '\n';
+            throw std::invalid_argument(msg);
+        }
+
     nav_->connect(top_block);
 
     // Synchronous ports
@@ -171,25 +179,25 @@ gr::basic_block_sptr Channel::get_left_block_trk()
     return trk_->get_left_block();
 }
 
+
 gr::basic_block_sptr Channel::get_right_block_trk()
 {
     return trk_->get_right_block();
 }
 
+
 gr::basic_block_sptr Channel::get_left_block_acq()
 {
-    if (flag_enable_fpga_)
-        {
-            LOG(ERROR) << "Enabled FPGA and called get_left_block() in channel interface";
-        }
     return acq_->get_left_block();
 }
 
+
 gr::basic_block_sptr Channel::get_right_block_acq()
 {
     return acq_->get_right_block();
 }
 
+
 gr::basic_block_sptr Channel::get_right_block()
 {
     return nav_->get_right_block();
