@@ -6,13 +6,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -21,21 +18,19 @@
 #ifndef GNSS_SDR_CONJUGATE_IC_H
 #define GNSS_SDR_CONJUGATE_IC_H
 
+#include "gnss_block_interface.h"
 #include <gnuradio/sync_block.h>
 #include <gnuradio/types.h>  // for gr_vector_const_void_star
-#if GNURADIO_USES_STD_POINTERS
-#include <memory>
-#else
-#include <boost/shared_ptr.hpp>
-#endif
+
+/** \addtogroup Algorithms_Library
+ * \{ */
+/** \addtogroup Algorithm_libs algorithms_libs
+ * \{ */
+
 
 class conjugate_ic;
 
-#if GNURADIO_USES_STD_POINTERS
-using conjugate_ic_sptr = std::shared_ptr<conjugate_ic>;
-#else
-using conjugate_ic_sptr = boost::shared_ptr<conjugate_ic>;
-#endif
+using conjugate_ic_sptr = gnss_shared_ptr<conjugate_ic>;
 
 conjugate_ic_sptr make_conjugate_ic();
 
@@ -55,4 +50,7 @@ private:
     conjugate_ic();
 };
 
-#endif
+
+/** \} */
+/** \} */
+#endif  // GNSS_SDR_CONJUGATE_IC_H
