@@ -1,7 +1,6 @@
 // SPDX-FileCopyrightText: 2017 Google LLC
 // SPDX-License-Identifier: Apache-2.0
 
-
 #ifndef CPU_FEATURES_INCLUDE_CPUINFO_X86_H_
 #define CPU_FEATURES_INCLUDE_CPUINFO_X86_H_
 
@@ -14,6 +13,8 @@ CPU_FEATURES_START_CPP_NAMESPACE
 #define CPU_FEATURES_VENDOR_GENUINE_INTEL "GenuineIntel"
 #define CPU_FEATURES_VENDOR_AUTHENTIC_AMD "AuthenticAMD"
 #define CPU_FEATURES_VENDOR_HYGON_GENUINE "HygonGenuine"
+#define CPU_FEATURES_VENDOR_CENTAUR_HAULS "CentaurHauls"
+#define CPU_FEATURES_VENDOR_SHANGHAI "  Shanghai  "
 
 // See https://en.wikipedia.org/wiki/CPUID for a list of x86 cpu features.
 // The field names are based on the short name provided in the wikipedia tables.
@@ -94,56 +95,70 @@ typedef struct
     int family;
     int model;
     int stepping;
-    char vendor[13];  // 0 terminated string
+    char vendor[13];        // 0 terminated string
+    char brand_string[49];  // 0 terminated string
 } X86Info;
 
 // Calls cpuid and returns an initialized X86info.
-// This function is guaranteed to be malloc, memset and memcpy free.
 X86Info GetX86Info(void);
 
 // Returns cache hierarchy informations.
 // Can call cpuid multiple times.
 // Only works on Intel CPU at the moment.
-// This function is guaranteed to be malloc, memset and memcpy free.
 CacheInfo GetX86CacheInfo(void);
 
 typedef enum
 {
     X86_UNKNOWN,
-    INTEL_CORE,        // CORE
-    INTEL_PNR,         // PENRYN
-    INTEL_NHM,         // NEHALEM
-    INTEL_ATOM_BNL,    // BONNELL
-    INTEL_WSM,         // WESTMERE
-    INTEL_SNB,         // SANDYBRIDGE
-    INTEL_IVB,         // IVYBRIDGE
-    INTEL_ATOM_SMT,    // SILVERMONT
-    INTEL_HSW,         // HASWELL
-    INTEL_BDW,         // BROADWELL
-    INTEL_SKL,         // SKYLAKE
-    INTEL_ATOM_GMT,    // GOLDMONT
-    INTEL_KBL,         // KABY LAKE
-    INTEL_CFL,         // COFFEE LAKE
-    INTEL_WHL,         // WHISKEY LAKE
-    INTEL_CNL,         // CANNON LAKE
-    INTEL_ICL,         // ICE LAKE
-    INTEL_TGL,         // TIGER LAKE
-    INTEL_SPR,         // SAPPHIRE RAPIDS
-    AMD_HAMMER,        // K8  HAMMER
-    AMD_K10,           // K10
-    AMD_K11,           // K11
-    AMD_K12,           // K12
-    AMD_BOBCAT,        // K14 BOBCAT
-    AMD_PILEDRIVER,    // K15 PILEDRIVER
-    AMD_STREAMROLLER,  // K15 STREAMROLLER
-    AMD_EXCAVATOR,     // K15 EXCAVATOR
-    AMD_BULLDOZER,     // K15 BULLDOZER
-    AMD_JAGUAR,        // K16 JAGUAR
-    AMD_PUMA,          // K16 PUMA
-    AMD_ZEN,           // K17 ZEN
-    AMD_ZEN_PLUS,      // K17 ZEN+
-    AMD_ZEN2,          // K17 ZEN 2
-    AMD_ZEN3,          // K19 ZEN 3
+    ZHAOXIN_ZHANGJIANG,  // ZhangJiang
+    ZHAOXIN_WUDAOKOU,    // WuDaoKou
+    ZHAOXIN_LUJIAZUI,    // LuJiaZui
+    ZHAOXIN_YONGFENG,    // YongFeng
+    INTEL_80486,         // 80486
+    INTEL_P5,            // P5
+    INTEL_LAKEMONT,      // LAKEMONT
+    INTEL_CORE,          // CORE
+    INTEL_PNR,           // PENRYN
+    INTEL_NHM,           // NEHALEM
+    INTEL_ATOM_BNL,      // BONNELL
+    INTEL_WSM,           // WESTMERE
+    INTEL_SNB,           // SANDYBRIDGE
+    INTEL_IVB,           // IVYBRIDGE
+    INTEL_ATOM_SMT,      // SILVERMONT
+    INTEL_HSW,           // HASWELL
+    INTEL_BDW,           // BROADWELL
+    INTEL_SKL,           // SKYLAKE
+    INTEL_ATOM_GMT,      // GOLDMONT
+    INTEL_KBL,           // KABY LAKE
+    INTEL_CFL,           // COFFEE LAKE
+    INTEL_WHL,           // WHISKEY LAKE
+    INTEL_CNL,           // CANNON LAKE
+    INTEL_ICL,           // ICE LAKE
+    INTEL_TGL,           // TIGER LAKE
+    INTEL_SPR,           // SAPPHIRE RAPIDS
+    INTEL_ADL,           // ALDER LAKE
+    INTEL_RCL,           // ROCKET LAKE
+    INTEL_KNIGHTS_M,     // KNIGHTS MILL
+    INTEL_KNIGHTS_L,     // KNIGHTS LANDING
+    INTEL_KNIGHTS_F,     // KNIGHTS FERRY
+    INTEL_KNIGHTS_C,     // KNIGHTS CORNER
+    INTEL_NETBURST,      // NETBURST
+    AMD_HAMMER,          // K8  HAMMER
+    AMD_K10,             // K10
+    AMD_K11,             // K11
+    AMD_K12,             // K12
+    AMD_BOBCAT,          // K14 BOBCAT
+    AMD_PILEDRIVER,      // K15 PILEDRIVER
+    AMD_STREAMROLLER,    // K15 STREAMROLLER
+    AMD_EXCAVATOR,       // K15 EXCAVATOR
+    AMD_BULLDOZER,       // K15 BULLDOZER
+    AMD_JAGUAR,          // K16 JAGUAR
+    AMD_PUMA,            // K16 PUMA
+    AMD_ZEN,             // K17 ZEN
+    AMD_ZEN_PLUS,        // K17 ZEN+
+    AMD_ZEN2,            // K17 ZEN 2
+    AMD_ZEN3,            // K19 ZEN 3
+    X86_MICROARCHITECTURE_LAST_,
 } X86Microarchitecture;
 
 // Returns the underlying microarchitecture by looking at X86Info's vendor,
@@ -153,7 +168,7 @@ X86Microarchitecture GetX86Microarchitecture(const X86Info* info);
 // Calls cpuid and fills the brand_string.
 // - brand_string *must* be of size 49 (beware of array decaying).
 // - brand_string will be zero terminated.
-// - This function calls memcpy.
+CPU_FEATURES_DEPRECATED("brand_string is now embedded in X86Info by default")
 void FillX86BrandString(char brand_string[49]);
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -237,4 +252,4 @@ CPU_FEATURES_END_CPP_NAMESPACE
 #error "Including cpuinfo_x86.h from a non-x86 target."
 #endif
 
-#endif  // CPU_FEATURES_INCLUDE_CPUINFO_X86_H
+#endif  // CPU_FEATURES_INCLUDE_CPUINFO_X86_H_
