@@ -7,13 +7,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -23,6 +20,8 @@
 #ifndef GNSS_SDR_HYBRID_OBSERVABLES_GS_H
 #define GNSS_SDR_HYBRID_OBSERVABLES_GS_H
 
+#include "gnss_block_interface.h"
+#include "gnss_time.h"  // for timetags produced by Tracking
 #include "obs_conf.h"
 #include <boost/circular_buffer.hpp>  // for boost::circular_buffer
 #include <gnuradio/block.h>           // for block
@@ -32,13 +31,17 @@
 #include <fstream>                    // for std::ofstream
 #include <map>                        // for std::map
 #include <memory>                     // for std::shared, std:unique_ptr
-#include <string>                     // for std::string
-#include <typeinfo>                   // for typeid
-#include <vector>                     // for std::vector
-#if GNURADIO_USES_STD_POINTERS
-#else
-#include <boost/shared_ptr.hpp>
-#endif
+#include <queue>
+#include <string>    // for std::string
+#include <typeinfo>  // for typeid
+#include <vector>    // for std::vector
+
+/** \addtogroup Observables
+ * \{ */
+/** \addtogroup Observables_gnuradio_blocks obs_gr_blocks
+ * GNU Radio blocks for the computation of GNSS observables
+ * \{ */
+
 
 class Gnss_Synchro;
 class hybrid_observables_gs;
@@ -46,11 +49,7 @@ class hybrid_observables_gs;
 template <class T>
 class Gnss_circular_deque;
 
-#if GNURADIO_USES_STD_POINTERS
-using hybrid_observables_gs_sptr = std::shared_ptr<hybrid_observables_gs>;
-#else
-using hybrid_observables_gs_sptr = boost::shared_ptr<hybrid_observables_gs>;
-#endif
+using hybrid_observables_gs_sptr = gnss_shared_ptr<hybrid_observables_gs>;
 
 hybrid_observables_gs_sptr hybrid_observables_gs_make(const Obs_Conf& conf_);
 
@@ -78,6 +77,8 @@ private:
     void update_TOW(const std::vector<Gnss_Synchro>& data);
     void compute_pranges(std::vector<Gnss_Synchro>& data) const;
     void smooth_pseudoranges(std::vector<Gnss_Synchro>& data);
+
+    void set_tag_timestamp_in_sdr_timeframe(const std::vector<Gnss_Synchro>& data, uint64_t rx_clock);
     int32_t save_matfile() const;
 
     Obs_Conf d_conf;
@@ -90,6 +91,8 @@ private:
         evSBAS_1C,
         evGAL_1B,
         evGAL_5X,
+        evGAL_E6,
+        evGAL_7X,
         evGLO_1G,
         evGLO_2G,
         evBDS_B1,
@@ -102,6 +105,9 @@ private:
 
     boost::circular_buffer<uint64_t> d_Rx_clock_buffer;  // time history
 
+    std::vector<std::queue<GnssTime>> d_SourceTagTimestamps;
+    std::queue<GnssTime> d_TimeChannelTagTimestamps;
+
     std::vector<bool> d_channel_last_pll_lock;
     std::vector<double> d_channel_last_pseudorange_smooth;
     std::vector<double> d_channel_last_carrier_phase_rads;
@@ -111,6 +117,8 @@ private:
     std::ofstream d_dump_file;
 
     double d_smooth_filter_M;
+    double d_T_rx_step_s;
+    double d_last_rx_clock_round20ms_error;
 
     uint32_t d_T_rx_TOW_ms;
     uint32_t d_T_rx_step_ms;
@@ -119,8 +127,11 @@ private:
     uint32_t d_nchannels_out;
 
     bool d_T_rx_TOW_set;  // rx time follow GPST
+    bool d_always_output_gs;
     bool d_dump;
     bool d_dump_mat;
 };
 
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_HYBRID_OBSERVABLES_GS_H
