@@ -20,7 +20,7 @@
 #ifndef GNSS_SDR_FMCOMMS2_SIGNAL_SOURCE_H
 #define GNSS_SDR_FMCOMMS2_SIGNAL_SOURCE_H
 
-#include "gnss_block_interface.h"
+#include "signal_source_base.h"
 #include <gnuradio/blocks/file_sink.h>
 #if GRIIO_INCLUDE_HAS_GNURADIO
 #include <gnuradio/iio/fmcomms2_source.h>
@@ -41,7 +41,7 @@
 
 class ConfigurationInterface;
 
-class Fmcomms2SignalSource : public GNSSBlockInterface
+class Fmcomms2SignalSource : public SignalSourceBase
 {
 public:
     Fmcomms2SignalSource(const ConfigurationInterface* configuration,
@@ -50,19 +50,6 @@ public:
 
     ~Fmcomms2SignalSource();
 
-    inline std::string role() override
-    {
-        return role_;
-    }
-
-    /*!
-     * \brief Returns "Fmcomms2_Signal_Source"
-     */
-    inline std::string implementation() override
-    {
-        return "Fmcomms2_Signal_Source";
-    }
-
     inline size_t item_size() override
     {
         return item_size_;
@@ -74,11 +61,21 @@ public:
     gr::basic_block_sptr get_right_block() override;
 
 private:
+    const std::string default_gain_mode = std::string("slow_attack");
+    const double default_tx_attenuation_db = -10.0;
+
+#if GNURADIO_API_IIO
+#if GR_IIO_TEMPLATIZED_API
+    gr::iio::fmcomms2_source<gr_complex>::sptr fmcomms2_source_f32c_;
+#else
+    gr::iio::fmcomms2_source::sptr fmcomms2_source_f32c_;
+#endif
+#else
     gr::iio::fmcomms2_source_f32c::sptr fmcomms2_source_f32c_;
+#endif
     gnss_shared_ptr<gr::block> valve_;
     gr::blocks::file_sink::sptr file_sink_;
 
-    std::string role_;
     std::string item_type_;
     std::string dump_filename_;
 
@@ -94,9 +91,6 @@ private:
     int64_t samples_;
     size_t item_size_;
 
-    unsigned int in_stream_;
-    unsigned int out_stream_;
-
     double rf_gain_rx1_;
     double rf_gain_rx2_;
     uint64_t freq_;  // frequency of local oscilator
@@ -105,14 +99,16 @@ private:
     uint64_t buffer_size_;  // reception buffer
     float Fpass_;
     float Fstop_;
+    unsigned int in_stream_;
+    unsigned int out_stream_;
     int RF_channels_;
 
     // DDS configuration for LO generation for external mixer
     double scale_dds_dbfs_;
     double phase_dds_deg_;
     double tx_attenuation_db_;
-    uint64_t freq_rf_tx_hz_;
     uint64_t freq_dds_tx_hz_;
+    uint64_t freq_rf_tx_hz_;
     uint64_t tx_bandwidth_;
     bool enable_dds_lo_;
 
