@@ -17,6 +17,9 @@
 #include "uhd_signal_source.h"
 #include "GPS_L1_CA.h"
 #include "configuration_interface.h"
+#include "gnss_sdr_create_directory.h"
+#include "gnss_sdr_filesystem.h"
+#include "gnss_sdr_string_literals.h"
 #include "gnss_sdr_valve.h"
 #include <glog/logging.h>
 #include <uhd/exception.hpp>
@@ -25,10 +28,13 @@
 #include <iostream>
 #include <utility>
 
+using namespace std::string_literals;
+
 
 UhdSignalSource::UhdSignalSource(const ConfigurationInterface* configuration,
     const std::string& role, unsigned int in_stream, unsigned int out_stream,
-    Concurrent_Queue<pmt::pmt_t>* queue) : role_(role), in_stream_(in_stream), out_stream_(out_stream)
+    Concurrent_Queue<pmt::pmt_t>* queue)
+    : SignalSourceBase(configuration, role, "UHD_Signal_Source"s), in_stream_(in_stream), out_stream_(out_stream)
 {
     // DUMP PARAMETERS
     const std::string empty;
@@ -62,8 +68,21 @@ UhdSignalSource::UhdSignalSource(const ConfigurationInterface* configuration,
         {
             // Single RF channel UHD operation (backward compatible config file format)
             samples_.push_back(configuration->property(role + ".samples", 0));
-            dump_.push_back(configuration->property(role + ".dump", false));
-            dump_filename_.push_back(configuration->property(role + ".dump_filename", default_dump_file));
+            bool dump_source = configuration->property(role + ".dump", false);
+            dump_.push_back(dump_source);
+            std::string dump_source_filename = configuration->property(role + ".dump_filename", default_dump_file);
+            dump_filename_.push_back(dump_source_filename);
+            if (dump_source)
+                {
+                    std::string::size_type pos = dump_source_filename.find_last_of(fs::path::preferred_separator);
+                    if (pos != std::string::npos)
+                        {
+                            if (!gnss_sdr_create_directory(dump_source_filename.substr(0, pos)))
+                                {
+                                    std::cerr << "GNSS-SDR cannot create the " << dump_source_filename.substr(0, pos) << " folder. Wrong permissions?\n";
+                                }
+                        }
+                }
 
             freq_.push_back(configuration->property(role + ".freq", GPS_L1_FREQ_HZ));
             gain_.push_back(configuration->property(role + ".gain", 50.0));
@@ -77,8 +96,21 @@ UhdSignalSource::UhdSignalSource(const ConfigurationInterface* configuration,
                 {
                     // Single RF channel UHD operation (backward compatible config file format)
                     samples_.push_back(configuration->property(role + ".samples" + std::to_string(i), 0));
-                    dump_.push_back(configuration->property(role + ".dump" + std::to_string(i), false));
-                    dump_filename_.push_back(configuration->property(role + ".dump_filename" + std::to_string(i), default_dump_file));
+                    bool dump_source = configuration->property(role + ".dump" + std::to_string(i), false);
+                    dump_.push_back(dump_source);
+                    std::string dump_source_filename = configuration->property(role + ".dump_filename" + std::to_string(i), std::to_string(i) + "_"s + default_dump_file);
+                    dump_filename_.push_back(dump_source_filename);
+                    if (dump_source)
+                        {
+                            std::string::size_type pos = dump_source_filename.find_last_of(fs::path::preferred_separator);
+                            if (pos != std::string::npos)
+                                {
+                                    if (!gnss_sdr_create_directory(dump_source_filename.substr(0, pos)))
+                                        {
+                                            std::cerr << "GNSS-SDR cannot create the " << dump_source_filename.substr(0, pos) << " folder. Wrong permissions?\n";
+                                        }
+                                }
+                        }
 
                     freq_.push_back(configuration->property(role + ".freq" + std::to_string(i), GPS_L1_FREQ_HZ));
                     gain_.push_back(configuration->property(role + ".gain" + std::to_string(i), 50.0));
