@@ -94,18 +94,27 @@ Gr_Complex_Ip_Packet_Source::make(std::string src_device,
 Gr_Complex_Ip_Packet_Source::Gr_Complex_Ip_Packet_Source(std::string src_device,
     __attribute__((unused)) const std::string &origin_address,
     int udp_port,
-    int udp_packet_size,
+    int udp_packet_size __attribute__((unused)),
     int n_baseband_channels,
     const std::string &wire_sample_type,
     size_t item_size,
     bool IQ_swap_)
     : gr::sync_block("gr_complex_ip_packet_source",
           gr::io_signature::make(0, 0, 0),
-          gr::io_signature::make(1, 4, item_size))  // 1 to 4 baseband complex channels
+          gr::io_signature::make(1, 4, item_size)),  // 1 to 4 baseband complex channels
+      d_pcap_thread(nullptr),
+      d_src_device(std::move(src_device)),
+      descr(nullptr),
+      fifo_buff(new char[FIFO_SIZE]),
+      fifo_read_ptr(0),
+      fifo_write_ptr(0),
+      fifo_items(0),
+      d_sock_raw(0),
+      d_udp_port(udp_port),
+      d_n_baseband_channels(n_baseband_channels),
+      d_IQ_swap(IQ_swap_)
 {
-    std::cout << "Start Ethernet packet capture\n";
-
-    d_n_baseband_channels = n_baseband_channels;
+    memset(reinterpret_cast<char *>(&si_me), 0, sizeof(si_me));
     if (wire_sample_type == "cbyte")
         {
             d_wire_sample_type = 1;
@@ -121,29 +130,19 @@ Gr_Complex_Ip_Packet_Source::Gr_Complex_Ip_Packet_Source(std::string src_device,
             d_wire_sample_type = 3;
             d_bytes_per_sample = d_n_baseband_channels * 8;
         }
+    else if (wire_sample_type == "ishort")
+        {
+            d_wire_sample_type = 4;
+            d_bytes_per_sample = d_n_baseband_channels * 4;
+        }
     else
         {
             std::cout << "Unknown wire sample type\n";
             exit(0);
         }
+    std::cout << "Start Ethernet packet capture\n";
+    std::cout << "Overflow events will be indicated by o's\n";
     std::cout << "d_wire_sample_type:" << d_wire_sample_type << '\n';
-    d_src_device = std::move(src_device);
-    d_udp_port = udp_port;
-    d_udp_payload_size = udp_packet_size;
-    d_fifo_full = false;
-
-    // allocate signal samples buffer
-    fifo_buff = new char[FIFO_SIZE];
-    fifo_read_ptr = 0;
-    fifo_write_ptr = 0;
-    fifo_items = 0;
-    d_item_size = item_size;
-    d_IQ_swap = IQ_swap_;
-    d_sock_raw = 0;
-    d_pcap_thread = nullptr;
-    descr = nullptr;
-
-    memset(reinterpret_cast<char *>(&si_me), 0, sizeof(si_me));
 }
 
 
@@ -224,7 +223,7 @@ Gr_Complex_Ip_Packet_Source::~Gr_Complex_Ip_Packet_Source()
         {
             delete d_pcap_thread;
         }
-    delete fifo_buff;
+    delete[] fifo_buff;
     std::cout << "Stop Ethernet packet capture\n";
 }
 
@@ -307,7 +306,7 @@ void Gr_Complex_Ip_Packet_Source::pcap_callback(__attribute__((unused)) u_char *
                     else
                         {
                             // notify overflow
-                            std::cout << "O" << std::flush;
+                            std::cout << "o" << std::flush;
                         }
                 }
         }
@@ -397,6 +396,25 @@ void Gr_Complex_Ip_Packet_Source::demux_samples(const gr_vector_void_star &outpu
                                 }
                         }
                     break;
+                case 4:  // interleaved short samples
+                    for (const auto &output_item : output_items)
+                        {
+                            int16_t real;
+                            int16_t imag;
+                            memcpy(&real, &fifo_buff[fifo_read_ptr], sizeof(real));
+                            fifo_read_ptr += 2;  // two bytes in short
+                            memcpy(&imag, &fifo_buff[fifo_read_ptr], sizeof(imag));
+                            fifo_read_ptr += 2;  // two bytes in short
+                            if (d_IQ_swap)
+                                {
+                                    static_cast<gr_complex *>(output_item)[n] = gr_complex(real, imag);
+                                }
+                            else
+                                {
+                                    static_cast<gr_complex *>(output_item)[n] = gr_complex(imag, real);
+                                }
+                        }
+                    break;
                 default:
                     std::cout << "Unknown wire sample type\n";
                     exit(0);
@@ -422,36 +440,20 @@ int Gr_Complex_Ip_Packet_Source::work(int noutput_items,
 
     if (output_items.size() > static_cast<uint64_t>(d_n_baseband_channels))
         {
-            std::cout << "Configuration error: more baseband channels connected than the available in the UDP source\n";
+            std::cout << "Configuration error: more baseband channels connected than available in the UDP source\n";
             exit(0);
         }
     int num_samples_readed;
     int bytes_requested;
-    switch (d_wire_sample_type)
+
+    bytes_requested = noutput_items * d_bytes_per_sample;
+    if (bytes_requested < fifo_items)
         {
-        case 1:  // complex byte samples
-        case 2:  // complex 4 bits samples
-        case 3:  // complex float samples
-            bytes_requested = noutput_items * d_bytes_per_sample;
-            if (bytes_requested < fifo_items)
-                {
-                    num_samples_readed = noutput_items;  // read all
-                }
-            else
-                {
-                    num_samples_readed = fifo_items / d_bytes_per_sample;  // read what we have
-                }
-            break;
-        default:  // complex byte samples
-            bytes_requested = noutput_items * d_bytes_per_sample;
-            if (bytes_requested < fifo_items)
-                {
-                    num_samples_readed = noutput_items;  // read all
-                }
-            else
-                {
-                    num_samples_readed = fifo_items / d_bytes_per_sample;  // read what we have
-                }
+            num_samples_readed = noutput_items;  // read all
+        }
+    else
+        {
+            num_samples_readed = fifo_items / d_bytes_per_sample;  // read what we have
         }
 
     bytes_requested = num_samples_readed * d_bytes_per_sample;
