@@ -90,19 +90,16 @@ private:
     std::string d_src_device;
     std::string d_origin_address;
     pcap_t *descr;  // ethernet pcap device descriptor
-    size_t d_item_size;
     char *fifo_buff;
     int fifo_read_ptr;
     int fifo_write_ptr;
     int fifo_items;
     int d_sock_raw;
     int d_udp_port;
-    int d_udp_payload_size;
     int d_n_baseband_channels;
     int d_wire_sample_type;
     int d_bytes_per_sample;
     bool d_IQ_swap;
-    bool d_fifo_full;
 };
 
 
