@@ -3,6 +3,7 @@
  * \brief Implementation of a Galileo unified INAV and FNAV message demodulator
  * block
  * \author Javier Arribas 2018. jarribas(at)cttc.es
+ * \author Carles Fernandez, 2021. cfernandez(at)cttc.es
  *
  *
  * -----------------------------------------------------------------------------
@@ -20,27 +21,31 @@
 #ifndef GNSS_SDR_GALILEO_TELEMETRY_DECODER_GS_H
 #define GNSS_SDR_GALILEO_TELEMETRY_DECODER_GS_H
 
-#include "galileo_cnav_message.h"
-#include "galileo_fnav_message.h"
-#include "galileo_inav_message.h"
-#include "gnss_block_interface.h"
-#include "gnss_satellite.h"
-#include "tlm_conf.h"
-#include <boost/circular_buffer.hpp>
-#include <gnuradio/block.h>  // for block
-#include <gnuradio/types.h>  // for gr_vector_const_void_star
-#include <cstdint>
-#include <fstream>
-#include <string>
-#include <vector>
+#include "galileo_cnav_message.h"     // for Galileo_Cnav_Message
+#include "galileo_fnav_message.h"     // for Galileo_Fnav_Message
+#include "galileo_inav_message.h"     // for Galileo_Inav_Message
+#include "gnss_block_interface.h"     // for gnss_shared_ptr (adapts smart pointer type to GNU Radio version)
+#include "gnss_satellite.h"           // for Gnss_Satellite
+#include "gnss_time.h"                // for GnssTime
+#include "nav_message_packet.h"       // for Nav_Message_Packet
+#include "tlm_conf.h"                 // for Tlm_Conf
+#include <boost/circular_buffer.hpp>  // for boost::circular_buffer
+#include <gnuradio/block.h>           // for block
+#include <gnuradio/types.h>           // for gr_vector_const_void_star
+#include <cstdint>                    // for int32_t, uint32_t
+#include <fstream>                    // for std::ofstream
+#include <memory>                     // for std::unique_ptr
+#include <string>                     // for std::string
+#include <vector>                     // for std::vector
 
 /** \addtogroup Telemetry_Decoder
  * \{ */
 /** \addtogroup Telemetry_Decoder_gnuradio_blocks
  * \{ */
 
-
-class galileo_telemetry_decoder_gs;
+class Viterbi_Decoder;               // forward declaration
+class Tlm_CRC_Stats;                 // forward declaration
+class galileo_telemetry_decoder_gs;  // forward declaration
 
 using galileo_telemetry_decoder_gs_sptr = gnss_shared_ptr<galileo_telemetry_decoder_gs>;
 
@@ -55,17 +60,16 @@ galileo_telemetry_decoder_gs_sptr galileo_make_telemetry_decoder_gs(
 class galileo_telemetry_decoder_gs : public gr::block
 {
 public:
-    ~galileo_telemetry_decoder_gs();
+    ~galileo_telemetry_decoder_gs() override;
     void set_satellite(const Gnss_Satellite &satellite);  //!< Set satellite PRN
     void set_channel(int32_t channel);                    //!< Set receiver's channel
     void reset();
-    int32_t flag_even_word_arrived;
 
     /*!
      * \brief This is where all signal processing takes place
      */
     int general_work(int noutput_items, gr_vector_int &ninput_items,
-        gr_vector_const_void_star &input_items, gr_vector_void_star &output_items);
+        gr_vector_const_void_star &input_items, gr_vector_void_star &output_items) override;
 
 
 private:
@@ -76,22 +80,14 @@ private:
 
     galileo_telemetry_decoder_gs(const Gnss_Satellite &satellite, const Tlm_Conf &conf, int frame_type);
 
-    const int32_t d_nn = 2;  // Coding rate 1/n
-    const int32_t d_KK = 7;  // Constraint Length
-
-    void viterbi_decoder(float *page_part_symbols, int32_t *page_part_bits);
     void deinterleaver(int32_t rows, int32_t cols, const float *in, float *out);
     void decode_INAV_word(float *page_part_symbols, int32_t frame_length);
     void decode_FNAV_word(float *page_symbols, int32_t frame_length);
     void decode_CNAV_word(float *page_symbols, int32_t page_length);
 
-    // vars for Viterbi decoder
+    std::unique_ptr<Viterbi_Decoder> d_viterbi;
     std::vector<int32_t> d_preamble_samples;
     std::vector<float> d_page_part_symbols;
-    std::vector<int32_t> d_out0;
-    std::vector<int32_t> d_out1;
-    std::vector<int32_t> d_state0;
-    std::vector<int32_t> d_state1;
 
     std::string d_dump_filename;
     std::ofstream d_dump_file;
@@ -105,13 +101,18 @@ private:
     Galileo_Inav_Message d_inav_nav;
     Galileo_Fnav_Message d_fnav_nav;
 
+    Nav_Message_Packet d_nav_msg_packet;
+    GnssTime d_current_timetag{};
+
+    std::unique_ptr<Tlm_CRC_Stats> d_Tlm_CRC_Stats;
+
     double d_delta_t;  // GPS-GALILEO time offset
 
     uint64_t d_sample_counter;
     uint64_t d_preamble_index;
     uint64_t d_last_valid_preamble;
 
-    int32_t d_mm = d_KK - 1;
+    int32_t d_mm;
     int32_t d_codelength;
     int32_t d_datalength;
     int32_t d_frame_type;
@@ -120,6 +121,7 @@ private:
     int32_t d_preamble_period_symbols;
     int32_t d_CRC_error_counter;
     int32_t d_channel;
+    int32_t d_flag_even_word_arrived;
 
     uint32_t d_PRN_code_period_ms;
     uint32_t d_required_symbols;
@@ -134,11 +136,17 @@ private:
     bool d_sent_tlm_failed_msg;
     bool d_flag_frame_sync;
     bool d_flag_PLL_180_deg_phase_locked;
-    bool d_flag_parity;
     bool d_flag_preamble;
     bool d_dump;
     bool d_dump_mat;
     bool d_remove_dat;
+    bool d_first_eph_sent;
+    bool d_cnav_dummy_page;
+    bool d_print_cnav_page;
+    bool d_enable_navdata_monitor;
+    bool d_dump_crc_stats;
+    bool d_enable_reed_solomon_inav;
+    bool d_valid_timetag;
 };
 
 
