@@ -116,7 +116,7 @@ public:
     void stop_tracking() override;
 
 private:
-    const std::string default_device_name = "multicorrelator_resampler_3_1_AXI";  // UIO device name
+    const std::string default_device_name_Galileo_E5a = "multicorrelator_resampler_3_1_AXI";  // UIO device name
 
     // the following flags are FPGA-specific and they are using arrange the values of the local code in the way the FPGA
     // expects. This arrangement is done in the initialisation to avoid consuming unnecessary clock cycles during tracking.
