@@ -24,12 +24,12 @@ double Galileo_Utc_Model::GST_to_UTC_time(double t_e, int32_t WN) const
     double t_Utc_daytime;
     double Delta_t_Utc = 0;
     // Determine if the effectivity time of the leap second event is in the past
-    const int32_t weeksToLeapSecondEvent = WN_LSF_6 - (WN % 256);
+    const int32_t weeksToLeapSecondEvent = WN_LSF - (WN % 256);
 
     if ((weeksToLeapSecondEvent) >= 0)  // is not in the past
         {
             // Detect if the effectivity time and user's time is within six hours  = 6 * 60 *60 = 21600 s
-            const int secondOfLeapSecondEvent = DN_6 * 24 * 60 * 60;
+            const int secondOfLeapSecondEvent = DN * 24 * 60 * 60;
             if (std::abs(t_e - secondOfLeapSecondEvent) > 21600)
                 {
                     /* 5.1.7a GST->UTC case a
@@ -39,7 +39,7 @@ double Galileo_Utc_Model::GST_to_UTC_time(double t_e, int32_t WN) const
                      * to the effective time and ends at six hours after the effective time,
                      * the GST/Utc relationship is given by
                      */
-                    Delta_t_Utc = Delta_tLS_6 + A0_6 + A1_6 * (t_e - t0t_6 + 604800 * static_cast<double>((WN % 256) - WNot_6));
+                    Delta_t_Utc = Delta_tLS + A0 + A1 * (t_e - tot + 604800 * static_cast<double>((WN % 256) - WNot));
                     t_Utc_daytime = fmod(t_e - Delta_t_Utc, 86400);
                 }
             else
@@ -49,9 +49,9 @@ double Galileo_Utc_Model::GST_to_UTC_time(double t_e, int32_t WN) const
                      * prior to the leap second adjustment to six hours after the adjustment time,
                      * the effective time is computed according to the following equations:
                      */
-                    Delta_t_Utc = Delta_tLS_6 + A0_6 + A1_6 * (t_e - t0t_6 + 604800 * static_cast<double>((WN % 256) - WNot_6));
+                    Delta_t_Utc = Delta_tLS + A0 + A1 * (t_e - tot + 604800 * static_cast<double>((WN % 256) - WNot));
                     const double W = fmod(t_e - Delta_t_Utc - 43200, 86400) + 43200;
-                    t_Utc_daytime = fmod(W, 86400 + Delta_tLSF_6 - Delta_tLS_6);
+                    t_Utc_daytime = fmod(W, 86400 + Delta_tLSF - Delta_tLS);
                     // implement something to handle a leap second event!
                 }
         }
@@ -64,7 +64,7 @@ double Galileo_Utc_Model::GST_to_UTC_time(double t_e, int32_t WN) const
              * ends six hours after the adjustment time, the effective time is computed according to
              * the following equation:
              */
-            Delta_t_Utc = Delta_tLSF_6 + A0_6 + A1_6 * (t_e - t0t_6 + 604800 * static_cast<double>((WN % 256) - WNot_6));
+            Delta_t_Utc = Delta_tLSF + A0 + A1 * (t_e - tot + 604800 * static_cast<double>((WN % 256) - WNot));
             t_Utc_daytime = fmod(t_e - Delta_t_Utc, 86400);
         }
 
