@@ -97,7 +97,7 @@ DECLARE_string(log_dir);
 #include "unit-tests/signal-processing-blocks/tracking/bayesian_estimation_test.cc"
 #if ARMADILLO_HAVE_MVNRND
 #include "unit-tests/signal-processing-blocks/tracking/cubature_filter_test.cc"
-#include "unit-tests/signal-processing-blocks/tracking/unscented_filter_test.cc"
+// #include "unit-tests/signal-processing-blocks/tracking/unscented_filter_test.cc"
 #endif
 #include "unit-tests/signal-processing-blocks/tracking/cpu_multicorrelator_real_codes_test.cc"
 #include "unit-tests/signal-processing-blocks/tracking/cpu_multicorrelator_test.cc"
@@ -126,6 +126,8 @@ DECLARE_string(log_dir);
 #include "unit-tests/signal-processing-blocks/pvt/rtcm_test.cc"
 #include "unit-tests/signal-processing-blocks/pvt/serdes_monitor_pvt_test.cc"
 #include "unit-tests/signal-processing-blocks/telemetry_decoder/galileo_fnav_inav_decoder_test.cc"
+#include "unit-tests/system-parameters/galileo_e1b_reed_solomon_test.cc"
+#include "unit-tests/system-parameters/galileo_e6b_reed_solomon_test.cc"
 #include "unit-tests/system-parameters/glonass_gnav_crc_test.cc"
 #include "unit-tests/system-parameters/glonass_gnav_ephemeris_test.cc"
 #include "unit-tests/system-parameters/glonass_gnav_nav_message_test.cc"
@@ -136,7 +138,7 @@ DECLARE_string(log_dir);
 // #include "unit-tests/signal-processing-blocks/acquisition/beidou_b3i_pcps_acquisition_test.cc"
 #include "unit-tests/signal-processing-blocks/acquisition/glonass_l1_ca_pcps_acquisition_test.cc"
 #include "unit-tests/signal-processing-blocks/acquisition/gps_l2_m_pcps_acquisition_test.cc"
-#include "unit-tests/signal-processing-blocks/pvt/rtklib_solver_test.cc"
+// #include "unit-tests/signal-processing-blocks/pvt/rtklib_solver_test.cc"
 #include "unit-tests/signal-processing-blocks/tracking/gps_l1_ca_dll_pll_tracking_test.cc"
 #include "unit-tests/signal-processing-blocks/tracking/gps_l1_ca_kf_tracking_test.cc"
 #include "unit-tests/signal-processing-blocks/tracking/gps_l2_m_dll_pll_tracking_test.cc"
